use rocket::{get, State};
use serde_json::json;

use crate::check_auth;
use crate::config::Config;
use crate::routes::Token;
use crate::{
    db::ItemDB,
    routes::{api_error, FallibleApiResponse},
};

use super::{item_does_not_exist_error, variant_does_not_exist_error};

#[get("/item/<item_id>/<variant_id>/price_history?<origin>")]
pub async fn variant_price_history_by_origin(
    item_id: &str,
    variant_id: &str,
    itemdb: &State<ItemDB>,
    t: Token,
    c: &State<Config>,
    origin: &str,
) -> FallibleApiResponse {
    check_auth!(t, c);

    let variant = itemdb
        .get_item(item_id)
        .ok_or_else(item_does_not_exist_error)?
        .variant(variant_id)
        .ok_or_else(variant_does_not_exist_error)?;

    Ok(json!(variant.price_history_by_origin(origin, None).await))
}

#[get("/item/<item_id>/<variant_id>/price_latest?<origin>")]
pub async fn variant_price_latest_by_origin(
    item_id: &str,
    variant_id: &str,
    itemdb: &State<ItemDB>,
    t: Token,
    c: &State<Config>,
    origin: &str,
) -> FallibleApiResponse {
    check_auth!(t, c);

    let variant = itemdb
        .get_item(item_id)
        .ok_or_else(item_does_not_exist_error)?
        .variant(variant_id)
        .ok_or_else(variant_does_not_exist_error)?;

    Ok(json!(variant
        .price_history_by_origin(origin, Some(1))
        .await
        .first()
        .unwrap()))
}
